#' Relative survival, AER and SMR based on French death rates
#' @title Relative survival, AER and SMR based on French death rates
#' @author Jean-Philippe Jais and Hugo Varet
#' @name survexp.fr-package
"_PACKAGE"
